#
# spec file for package aespipe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aespipe
Version:        2.4g
Release:        1.3
Summary:        AES Encrypting/Decrypting Pipe
License:        GPL-2.0-only
URL:            https://loop-aes.sourceforge.net/
Source0:        https://loop-aes.sourceforge.net/aespipe/%{name}-v%{version}.tar.bz2#/%{name}-%{version}.tar.bz2
Source1:        https://loop-aes.sourceforge.net/aespipe/%{name}-v%{version}.tar.bz2.sign#/%{name}-%{version}.tar.bz2.sign
Source2:        %{name}.keyring
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gpg2
Requires:       gpg2

%description
aespipe program is AES encrypting or decrypting pipe. It reads from standard
input and writes to standard output. It can be used to create and restore
encrypted tar or cpio archives. It can be used to encrypt and decrypt loop-AES
compatible encrypted disk images.

%prep
%setup -q -n %{name}-v%{version}
patch  < aes-GPL.diff

%build
autoreconf -fiv
%configure \
CFLAGS="$CFLAGS -fno-strict-aliasing" \
LDFLAGS="$LDFLAGS -fno-strict-aliasing" \
%ifarch %{ix86}
  --enable-asm=x86   --enable-padlock --enable-intelaes \
%endif
%ifarch amd64 x86_64 ia32e em64t
  --enable-asm=amd64 --enable-padlock --enable-intelaes \
%endif
  --disable-silent-rules
%make_build

%check
%make_build tests

%install
%make_install
install -D -p -m 0755 bz2aespipe \
  %{buildroot}%{_bindir}/bz2aespipe

%files
%doc ChangeLog README
%{_bindir}/aespipe
%{_bindir}/bz2aespipe
%{_mandir}/man1/aespipe.1%{?ext_man}

%changelog
* Fri Jan 26 2024 ming li <mli@suse.com>
- Update to version 2.4g:
  * Added configure script autodetection for -fno-strict-aliasing compile
    flag. This option is needed with some compilers that miscompile code
    when link-time-optimization is used.
* Tue Nov 15 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Homepage link http://loop-aes.sourceforge.net/ is a permanent
  redirect to its HTTPS counterpart https://loop-aes.sourceforge.net/
* Thu Oct 21 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Re-enable LTO, but disable strict aliasing - boo#1187352
* Mon Jun 28 2021 Andreas Schwab <schwab@suse.de>
- Disable LTO everywhere (bsc#1187352)
* Tue Jun 15 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable LTO for aarch64, %%{arm} and ppc64le as a workaround for boo#1187352
* Wed Jul 29 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to 2.4f
  * Fixed configure script mis-detection of "labels need underline
    prefix" on Fedora. Fix from Jiri Hladky.
  * Added configure script autodetection for x86/amd64 -fno-pie compile
    and -no-pie linker flags. These are needed when compiler/linker
    produces position independent executable (PIE) by default.
- Run spec-cleaner
- Add source verification
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to 2.4e
  * Added workaround for gpg 2 pinentry-mode bug.
- Cleanup spec file with spec-cleaner
* Mon Jun  5 2017 mpluskal@suse.com
- Fix building on Factory (disable pie building)
* Sat Apr  1 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Fri Mar 31 2017 meissner@suse.com
- Disable PIE linking, as the assembler code is not position independ
  currently.
* Fri Feb 24 2017 shshyukriev@suse.com
- Compile with -fPIC for 64bit to fix build errors
* Thu Jun  4 2015 mpluskal@suse.com
- Update to 2.4d
  * no upstream changelog available
- Cleanup spec file with spec-cleaner
- Drop no longer needed aespipe-ppc64le.patch
* Tue Jul 29 2014 dvaleev@suse.com
- Fix PowerPC little endian build
- added patches:
  * aespipe-ppc64le.patch
* Sun Apr  1 2012 bruno@ioda-net.ch
- Fix spec formatting and licence
* Sat Jan 21 2012 bruno@ioda-net.ch
- New packaging for obs / version 2.4.c
* Sun Oct 28 2007 jnelson@jamponi.net
- tweaks for build service
* Fri Apr  6 2007 guru@unixtech.be
- new upstream version
* Mon Dec 11 2006 guru@unixtech.be
- new package
